#
# spec file for package csound
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define py3version %(pkg-config python3 --modversion)
%define support_fltk 1
%bcond_with python

%if 0%{?suse_version} > 1500
%bcond_with java
%else
%bcond_with java
%endif

%define maj 6
%define min 0

Name:           csound
Version:        6.18.1
Release:        3.5
Summary:        Computer Sound Synthesis and Composition Program
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://www.csounds.com
Source0:        https://github.com/csound/csound/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
#Source0:        %{name}-%{version}.tar.xz
Source1:        README.SUSE
Source2:        COPYING_gpl2+.txt
# Default to using pulseaudio instead of portaudio
Patch2:         csound-6.08-default-pulse.patch
# Use xdg-open to open a browser to view the manual
Patch4:         csound-6.08-xdg-open.patch
Patch5:         csound-rename-sndinfo.patch
BuildRequires:  alsa-devel
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  eigen3-devel
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  fluidsynth-devel
BuildRequires:  gcc-c++
BuildRequires:  jack-devel
%if %{with java}
BuildRequires:  java-devel-openjdk
%endif
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  liblo-devel
BuildRequires:  libsndfile-devel
BuildRequires:  lua-devel
BuildRequires:  portaudio-devel
BuildRequires:  swig
%if %{with python}
BuildRequires:  python3-devel
%endif
%if %support_fltk
BuildRequires:  fltk-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
%endif
Recommends:     %{name}-lang

%global luaver %(lua -v | sed -r 's/Lua ([[:digit:]]+\\.[[:digit:]]+).*/\\1/')

%description
Csound is a software synthesis program. It is modular and
supports an unlimited amount of oscillators and filters.

%package -n libcsnd6-%{maj}_%{min}
Summary:        Computer sound synthesis and composition library
Group:          System/Libraries

%description -n libcsnd6-%{maj}_%{min}
Library for csound use.
Csound is a software synthesis program supporting oscillators and
filters.

%package -n libcsound64-%{maj}_%{min}
Summary:        Computer sound synthesis and composition library
Group:          System/Libraries

%description -n libcsound64-%{maj}_%{min}
Library for csound use
Csound is a software synthesis program supporting oscillators and
filters.

%package java-bindings
Summary:        Java bindings for the Csound sound synthesis and composition library
Group:          System/Libraries

%description java-bindings
Java bindings for csound use.
Csound is a software synthesis program supporting oscillators and
filters.

%package plugins
Summary:        Plugins for csound
Group:          Productivity/Multimedia/Other

%description plugins
Plugins for csound

%package -n python3-csound
Summary:        Csound opcodes for python
Group:          Productivity/Multimedia/Other

%description -n python3-csound
Csound opcodes for python

%package samples
Summary:        Data files for csound
License:        MIT
Group:          Productivity/Multimedia/Other
BuildArch:      noarch

%description samples
HRTF datafiles and Soundfont for csound

%package devel
Summary:        Development files for Csound
Group:          Development/Libraries/C and C++
%if %{with java}
Requires:       %{name}-java-bindings = %{version}
%endif
Requires:       libcsnd6-%{maj}_%{min} = %{version}
Requires:       libcsound64-%{maj}_%{min} = %{version}

%description devel
Development files for Csound, a sound synthesis program.

%lang_package

%prep
%autosetup -p1
# remove __DATE__ from source files, causes unnecessary rebuilds
#sed -i 's:__DATE__:"":' Engine/musmon.c include/version.h Top/main.c
# copy readme
cp %{SOURCE1} %{SOURCE2} .
#These source files are undistributable
#rm -f Opcodes/scansyn*
head -n 28 util/SDIF/sdif.c > COPYING.PostgreSQL

%build
# Needed to link libbuchla.so
export CFLAGS="%{optflags} -lm"
export CXXFLAGS="%{optflags} -std=c++11"

%cmake \
       -DBUILD_SCANSYN_OPCODES=OFF \
%if %{with python}
       -DPYTHON_LIBRARY="%{_libdir}/libpython$(pkg-config python3 --modversion)$(python3-config --abiflags).so" \
       -DPYTHON_INCLUDE_DIR="%{_includedir}/python$(pkg-config python3 --modversion)$(python3-config --abiflags)" \
%endif
       -DNEED_PORTTIME:BOOL=OFF \
       -DRPM_LUAVER:STRING=%{luaver} \
%if "%{_lib}" == "lib64"
       -DUSE_LIB64:BOOL=ON
%else
       -DUSE_LIB64:BOOL=OFF
%endif

%make_build

%install
%cmake_install
#python bindings are wip
rm -rf %{buildroot}root
cp -v OOps/README.md README.OOps

%fdupes -s %{buildroot}
%find_lang %{name}%{maj}

%post -n libcsnd6-%{maj}_%{min} -p /sbin/ldconfig
%postun -n libcsnd6-%{maj}_%{min} -p /sbin/ldconfig

%post -n libcsound64-%{maj}_%{min} -p /sbin/ldconfig
%postun -n libcsound64-%{maj}_%{min} -p /sbin/ldconfig

%post java-bindings -p /sbin/ldconfig
%postun java-bindings -p /sbin/ldconfig

%files
%doc AUTHORS README.md README.SUSE Release_Notes README.OOps
%license COPYING COPYING_gpl2+.txt COPYING.PostgreSQL
%{_bindir}/*

%files -n libcsnd6-%{maj}_%{min}
%{_libdir}/libcsnd6.so.%{maj}.%{min}

%files -n libcsound64-%{maj}_%{min}
%{_libdir}/libcsound64.so.%{maj}.%{min}

%if %{with java}
%files java-bindings
%{_libdir}/lib_jcsound6.so
%{_libdir}/csnd6.jar
%endif

%files plugins
%{_libdir}/csound/

%files samples
%{_datadir}/samples/

%files -n python3-csound
%if 0%{?suse_version} > 1500
%{python_sitearch}/ctcsound.py
%else
%{_libdir}/python3.6/site-packages/ctcsound.py
%endif

%files devel
%{_includedir}/csound/
%{_libdir}/libcs*.so
%{_datadir}/cmake/Csound/

%files lang -f %{name}%{maj}.lang

%changelog
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Drop unused BuildRequire on xorg-x11-devel
- Modernize specfile constructs
* Wed Dec 14 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 6.18.1
  * A long-standing big-endian test failure with score strings has been fixed.
  * The symbol spillage caused by a build misconfiguration has been resolved.
  * Plugin ABI compatibility with earlier versions (affecting the FLTK plugin) has been restored
  * Some left-over tracing in the mod function has been removed.
- Version 6.18.0 Changes:
  New opcodes
  * scanmap reads internal state of scanu
  * elapsedcycles, elapsedtime, eventcycles, and eventtime. See under
    "bugs fied" for detials.
  Modified Opcodes and Gens
  * fix midi list printing to stdout part of the list.
  Bugs Fixed
  * Fixed bug where fixed-point phase computation (in oscil family) was
    incorrect resulting in slight freq deviations in very low freq cases.
  * Fixed bug where freeing instr 0 caused memory issues in new
    compilations. Instr 0 is not freed until reset now.
  * Fixed a bug where opcode directory search was crashing Csound if HOME
    variable not set.
  * Fixed pol2rect array size setting.
  * OSCsend, OSCsend_lo and OSClisten can now work with OSC messages
    carrying no payload (as per spec and manual).
  * bug in sum fixed
  * 'pitchamd' opcode causes segmentation fault (macOS) (#1599)
  * fixed crash on channel setting with empty channel name
  * bug in ftloadk fixed (#1611)
  * qnan works even when compiled with fast arithmetic
  * Fix the flanger opcode for sample-accurate mode, where the xdel input was
    not being correctly offset.
  * elapsedcycles, elapsedtime, eventcycles, and eventtime introducd as
    fixed versions of timek, times, timeinstk and timeinsts but return
    the correct values instead of being one cycle late. This prserves
    backward compatability
  System Changes
  * Fix for issue #1613:
    Fixes the rtauhal module for all cases of multichannel output. Previously the
    module would not work correctly with some devices.
  * Csound now supports MP3 files for input and output through libsndfile
    (version 1.1.0 and higher).
  Platform Specific
  Bela:
  * Many changes to Bela csound. See bela web site for details
  MacOS:
  * Universal build for x86_64 and arm64, backward compatible to MacOS 10.9
  WASM:
  * fix sampleRate for single-thread worklet
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 6.18.1:
  * This is a patchfix release mainly dealing with issues arisen in Linux
    package management. This contains the same code as 6.18.0, except for:
  * A long-standing big-endian test failure with score strings has been
    fixed.
  * The symbol spillage caused by a build misconfiguration has been
    resolved.
  * Plugin ABI compatibility with earlier versions (affecting the FLTK
    plugin) has been restored
  * Some left-over tracing in the mod function has been removed.
- update to 6.18.0:
  * Mainly a bug-fixing release.  Major new facility is MP3 (MPEG) audio
  * files are supported both for input and output in platforms where this is
  * supported by libsndfile.
  * fix midi list printing to stdout part of the list.
  * Fixed bug where fixed-point phase computation (in oscil family) was
  * incorrect resulting in slight freq deviations in very low freq cases.
  * Fixed bug where freeing instr 0 caused memory issues in new
  * compilations. Instr 0 is not freed until reset now.
  * Fixed a bug where opcode directory search was crashing Csound if HOME
  * variable not set.
  * Fixed pol2rect array size setting.
  * OSCsend, OSCsend_lo and OSClisten can now work with OSC messages
  * carrying no payload (as per spec and manual).
  * bug in sum fixed
  * elapsedcycles, elapsedtime, eventcycles, and eventtime introducd as
  * fixed versions of timek, times, timeinstk and timeinsts but return
  * the correct values instead of being one cycle late.  This prserves
  * backward compatability
  * Csound now supports MP3 files for input and output through libsndfile
* Fri Aug 12 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 6.17.0
  USER-LEVEL CHANGES
  New opcodes
  * scanmap and scansmap are like the xscanmap/xscansmap opcodes but
    work with the mainstream scan opcodes.
  * trigexpseg, triglinseg are aliases for trigExpseg, trigLinseg.
  * xscan opcodes are deprecated as they add nothing to the scan opcodes.
  * bformdec2 provides more ambisonic decoding of bformat audio.
  * metrobpm is like metro but the timing is in beats per minute and the
    signal can be offset by a proportion of the cycle.
  * sequ is a csound version of a hardware sequencer. It has many modes and options.
  * gtadsr implements a gated ADSR envelope
  Orchestra
  * Message printing has been revised so -m16 suppresses all
    messages.
  * add channel count to list_audio_devices (called when the flag
  - -devices is used so that it can be parsed by frontends).
  Modified Opcodes and Gens
  * event opcode does not bail out if the instrument called does not exist.
  * Added an optional prefix to soundfont instruments printed via sfilist.
  * lpslots reworked with better control.
  Utilities
  * cvanal now uses the SADIR environment to look for analysis files.
  Bugs Fixed
  * fareylen called a non-existent function leading to a crash. Removed typo.
  * turnoff could cause clicks in some cases; fixed.
  * turnoff3 improved.
  * cntReset fixed; had a false initialisation code.
  * binary search in bpf fixed.
  * pvscfs frame counting issue fixed.
  * --sample-accurate fixed in a-rate form of tabsum.
  * Problem in atssinnoi fixed; did read outside allocated memory.
  * hrtfmove fixed; it could use the wrong value for sr.
  * Named instruments could use wrong structure in redefinition.
  * fixes in the jack backend relating to --get-system-sr.
  * pvcross frequency warp mode fixed.
  * lpcfilter/lpcanal bug where processing could not be restarted after
    a freeze fixed.
  * the emugens collection of opcode, a large group incorporation mainly
    array operations, were not made available due to a small editing
    error.
  * If using a float build (rather than a double) array access could be
    wrong.
  * In some cases instr0 code could ignore loops after an incorrect
    warning. Now fixed.
  * Bugs in mp3len and similar fixed.
  * Crash in syncgrain issue #1773 fixed
  * UDO output of fsigs fixed.
  SYSTEM LEVEL CHANGES
  System Changes
  * winsound has been removed.
  API
  * CreateThread2 is a new API function that allows threads to be given a
    user-defined stack size.
* Wed Jan 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.16.2:
  * This is a hotfix release dealing with an issue that prevented
    CsoundQT successfully producing a recording using one of the
    API threading services. Fixes for desktop OS packages affected
    are provided here.
- Changes from version 6.16.1:
  * This is a bug fix release of Csound 6.16, where an issue
    affecting the use of turnoff/turnoff2 was repaired.
* Tue Jun 29 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 6.16.0
- add python3-csound package
- update csound-rename-sndinfo.patch
* Wed May 26 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 6.15.0
- add -samples subpackage
* Sat Feb 20 2021 Dave Plater <davejplater@gmail.com>
- Added quotes to %%{_lib} conditional to satisfy new rpmlint.
* Fri Jul 10 2020 Dave Plater <davejplater@gmail.com>
- Removed unused util/new_srconv.c from sources to fix licensing.
* Wed Jun  3 2020 davejplater@gmail.com
- Update to version 6.14.0+git20200601 and fix factory build
- Use service file instead of pre_checkin.sh to create tarball.
- Remove incorporated patche fluidsynth2.patch.
  * init
  * resonbnk and apoleparams
  * fix to multicore + etter code
  * resonator bank
  * fix prepiano meory issue
  * allpoleb opcode
  * Nearly there
  * coeffs to params fix
* Wed Jun 26 2019 Dave Plater <davejplater@gmail.com>
- Renamed sndifo to csndinfo again to fix conflict with snd package
  using csound-rename-sndinfo.patch this time.
* Wed Jun  5 2019 Dave Plater <davejplater@gmail.com>
- Added pre_checkin.sh to remove undistributable scansyn files from
  the source tarball.
- Relicenced to GPL-2.0-or-later AND BSD-3-Clause AND PostgreSQL
  GPL-2.0 or later source file which relicenses the LGPL sources
- Added COPYING_gpl2+.txt to licenses.
* Tue Apr  9 2019 Jan Engelhardt <jengelh@inai.de>
- Update summaries.
* Sat Apr  6 2019 plater <davejplater@gmail.com>
- Update to version 6.12.2 and fix Factory build.
- Remove obsolete patches:
  csound-scons-on-py3.patch and csound-strncat-fix.patch
- Added fluidsynth2.patch from Arch linux
- Added csound-6.08-default-pulse.patch, csound-6.08-xdg-open.patch
  from Fedora.
- Now builds with cmake
- For upstream changes see:
  /usr/share/doc/packages/csound/Release_Notes/
* Thu Nov 23 2017 dimstar@opensuse.org
- Add csound-scons-on-py3.patch: Fix build with scons using python3
  as interpreter.
* Wed Nov  8 2017 dimstar@opensuse.org
- Rename README.SuSE to README.SUSE, adhering to the correct
  spelling.
* Sat Feb 11 2017 jengelh@inai.de
- Fix RPM groups, trim descriptions from repeated information.
  Remove unnecessary ldconfig calls (they do not apply for
  plugin directories).
* Mon Jan 16 2017 bwiedemann@suse.com
- drop useless uninstall script and make build reproducible
* Tue Nov  6 2012 tiwai@suse.de
- updated to version 5.18.02, including previous security fixes:
  this fixes the build failure on FACTORY with new bison, too;
  see ChangeLog for detailed updates and fixes
* Wed Apr 18 2012 tiwai@suse.de
- VUL-0: csound: buffer overflow in pv_import (CVE-2012-2106,
  bnc#757254),
  VUL-0: csound: buffer overflow in lpc_import (CVE-2012-2107,
  bnc#757255),
  VUL-0: csound: Stack-based buffer overflow in lpc_import
  (CVE-2012-2108, bnc#757256):
  a single patch for all three issues
* Mon Feb 27 2012 tiwai@suse.de
- updated to version 5.16.6, including a fix for
  VUL-0: CVE-2012-0270: csound: two buffer overflow flaws in
  getnum() (bnc#749073)
- drop obsoleted patches
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to version 5.15.0
- drop unused patches
- fix wrong memset and strncat usage ({memset,strncat}-fix.patch)
- create -devel subpackage
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Jul 16 2009 tiwai@suse.de
- fix scons argument to build for 64bit archs (bnc#521979)
* Wed Jan 28 2009 tiwai@suse.de
- Fix python module search path insecure issue (bnc#470095)
  This package is unaffected; the patch is included just for any
  possible cases in future.
* Wed Oct  1 2008 tiwai@suse.de
- fix build with python-2.6
* Wed Jun 20 2007 tiwai@suse.de
- fix fdupes usage
* Mon Jun 11 2007 tiwai@suse.de
- updated to version 5.06:
  * fix k-rate, vrandh and vrandi scaling problems, mod fix
  * new opcodes: partikkel, partikkelsync
* Tue Mar 27 2007 tiwai@suse.de
- update to version 5.05:
  * fixes/improvements on FLTK support
  * fix heap overflow
  * clean up old codes
* Mon Jan 22 2007 tiwai@suse.de
- major update to version 5.04
  (not built with fltk due to lack of threading support)
* Mon Mar 27 2006 pth@suse.de
- Add missing parameter in printf call (bug #129676).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Oct 15 2004 tiwai@suse.de
- renamed extract to csound-extract to avoid name confliction
  (bug #45347).
* Wed Jun  2 2004 tiwai@suse.de
- fixed the ALSA RT plugin with the new API.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Tue Aug  5 2003 tiwai@suse.de
- renamed sndinfo to csndinfo to avoid name confliction with snd.
* Wed Jul 30 2003 tiwai@suse.de
- fixed the build on x86-64.
* Mon Jul 28 2003 tiwai@suse.de
- updated to 4.24.1.
- fixed tmpnam with mkstemp.
* Thu Feb  1 2001 tiwai@suse.de
- Initial vesrion: unofficial-4.10.0.0c
